@@ -18,7 +18,7 @@ from pint.errors import UndefinedUnitError
 
 from vivarium.library.datum import Datum
 from vivarium.library.topology import inverse_topology
-from vivarium.library.units import Quantity
+from vivarium.library.units import Quantity, Unit
 from vivarium.core.registry import serializer_registry
 from vivarium.library.dict_utils import deep_merge
 from vivarium.core.types import (
@@ -80,6 +80,9 @@ def serialize_value(value: Any) -> Any:
     if isinstance(value, Quantity):
         value = cast(Quantity, value)
         return serializer_registry.access('units').serialize(value)
+    if isinstance(value, Unit):
+        value = cast(Unit, value)
+        return serializer_registry.access('units').serialize(value)
     if callable(value):
         value = cast(Callable, value)
         return serializer_registry.access('function').serialize(value)
@@ -232,7 +235,8 @@ def _get_composite_state(
                 topology=subtopology,
                 state_type=state_type,
                 path=subpath,
-                initial_state=initial_state
+                initial_state=initial_state,
+                config=config.get(key),
             )
         elif isinstance(node, Process):
             if state_type == 'initial':
@@ -305,22 +309,23 @@ class Composite(Datum):
             composite: Optional['Composite'] = None,
             processes: Optional[Dict[str, 'Process']] = None,
             topology: Optional[Topology] = None,
+            path: Optional[HierarchyPath] = None,
             schema_override: Optional[Schema] = None,
     ) -> None:
         composite = composite or Composite({})
         processes = processes or {}
         topology = topology or {}
+        path = path or tuple()
         schema_override = schema_override or {}
 
         if composite:
             processes.update(composite['processes'])
             topology.update(composite['topology'])
 
-        for process in processes.values():
-            assert isinstance(process, Process)
-
-        self.processes.update(processes)
-        self.topology.update(topology)
+        processes = assoc_in({}, path, processes)
+        topology = assoc_in({}, path, topology)
+        deep_merge(self.processes, processes)
+        deep_merge(self.topology, topology)
         self._schema.update(schema_override)
         _override_schemas(self._schema, self.processes)
 
@@ -468,7 +473,7 @@ class Composer(metaclass=abc.ABCMeta):
         return composite.get_parameters()
 
 
-class AggregateComposer(Composer):
+class MetaComposer(Composer):
 
     def __init__(
             self,
@@ -561,9 +566,7 @@ class Process(Composer, metaclass=abc.ABCMeta):
             dict: Subclass implementations must return a dictionary
             mapping state paths to initial values.
         """
-        raise Exception(
-            '{} does not include an "initial_state" function'.format(
-                self.name))
+        return {}
 
     def generate_processes(
             self, config: Optional[dict] = None) -> Dict[str, Any]:
