@@ -72,7 +72,7 @@ def dict_to_paths(root, d):
         return [(root, d)]
         
 
-def inverse_topology(outer, update, topology):
+def inverse_topology(outer, update, topology, inverse=None):
     '''
     Transform an update from the form its process produced into
     one aligned to the given topology.
@@ -83,7 +83,8 @@ def inverse_topology(outer, update, topology):
     to calculate.
     '''
 
-    inverse = {}
+    inverse = inverse or {}
+
     for key, path in topology.items():
         if key == '*':
 
@@ -91,18 +92,16 @@ def inverse_topology(outer, update, topology):
                 node = inverse
                 if '_path' in path:
                     inner = normalize_path(outer + path['_path'])
-                    node = get_in(inverse, inner)
-                    if node is None:
-                        node = {}
-                        assoc_path(inverse, inner, node)
                     path = without(path, '_path')
+                else:
+                    inner = outer
 
                 for child, child_update in update.items():
-                    node[child] = inverse_topology(
-                        tuple(),
+                    inverse = inverse_topology(
+                        inner + (child,),
                         update[child],
-                        path)
-
+                        path,
+                        inverse)
             else:
                 for child, child_update in update.items():
                     inner = normalize_path(outer + path + (child,))
@@ -118,26 +117,21 @@ def inverse_topology(outer, update, topology):
         elif key in update:
             value = update[key]
             if isinstance(path, dict):
-                node = inverse
                 if '_path' in path:
                     inner = normalize_path(outer + path['_path'])
-                    node = get_in(inverse, inner)
-                    if node is None:
-                        node = {}
-                        assoc_path(inverse, inner, node)
                     path = without(path, '_path')
 
                     for update_key in update[key].keys():
                         if update_key not in path:
                             path[update_key] = (update_key,)
+                else:
+                    inner = outer
 
-                deep_merge(
-                    node,
-                    inverse_topology(
-                        tuple(),
-                        value,
-                        path))
-
+                inverse = inverse_topology(
+                    inner,
+                    value,
+                    path,
+                    inverse)
             else:
                 inner = normalize_path(outer + path)
                 if isinstance(value, dict):
@@ -157,7 +151,7 @@ def normalize_path(path):
             progress = progress[:-1]
         else:
             progress.append(step)
-    return progress
+    return tuple(progress)
 
 
 class TestUpdateIn:
